
CREATE TABLE server_generation
(
  servergeneration    	  bigint NOT NULL,
  description 	  	 	  character varying(128),
  CONSTRAINT server_generation_pkey PRIMARY KEY (servergeneration)
);

CREATE TABLE operational_status
(
  operationalstatus    	  bigint NOT NULL,
  description 	  	 	  character varying(128),
  CONSTRAINT server_operational_status_pkey PRIMARY KEY (operationalstatus)
);

CREATE TABLE server_device
(
  serverid bigint NOT NULL,
  servergeneration bigint NOT NULL,
  platformguid character varying(128),
  manufacturer  character varying(255),
  numberofcpu integer,
  totalmemory  bigint,
  sdcardpresence boolean default 'f',
  chassisservicetag character varying(128),
  cisorstatus character varying(128),
  templateid bigint,
  operationalstatus bigint,
  CONSTRAINT server_device_pkey PRIMARY KEY (serverid),
  CONSTRAINT fk_server_device_device FOREIGN KEY (serverid)
      REFERENCES infrastructure_device (deviceid) MATCH SIMPLE ON UPDATE CASCADE ON DELETE CASCADE,
  CONSTRAINT fk_server_device_operational_status FOREIGN KEY (operationalstatus)
      REFERENCES operational_status (operationalstatus) MATCH SIMPLE ON UPDATE CASCADE ON DELETE CASCADE,
  CONSTRAINT fk_server_device_server_generation FOREIGN KEY (servergeneration)
      REFERENCES server_generation (servergeneration) MATCH SIMPLE ON UPDATE CASCADE ON DELETE CASCADE
);

CREATE TABLE server_network_interface
(
  serverid 					bigint NOT NULL,
  servernetworkinterfaceid 	bigint NOT NULL,
  currentmacaddress 		character varying(128),
  permanentmacaddress   	character varying(128),
  fqdd   					character varying(255),
  productname 				character varying(255),
  vendorname				character varying(255),
  CONSTRAINT server_network_interface_pkey PRIMARY KEY (serverid, servernetworkinterfaceid),
  CONSTRAINT fk_server_network_interface_server FOREIGN KEY (serverid)
      REFERENCES server_device (serverid) MATCH SIMPLE ON UPDATE CASCADE ON DELETE CASCADE
);

CREATE TABLE host
(
  serverid 		   bigint NOT NULL,
  hostid 		   bigint NOT NULL,
  osname 		   character varying(255),
  osversion  	   character varying(255),
  hostname         character varying(255),
  ipaddress        character varying(30),
  managedobjectid  character varying(128),
  vmmaddress       character varying(255),
  iscompliant   boolean default 'f',
  CONSTRAINT host_pkey PRIMARY KEY (serverid, hostid),
  CONSTRAINT fk_host_server_device FOREIGN KEY (serverid)
      REFERENCES server_device (serverid) MATCH SIMPLE ON UPDATE CASCADE ON DELETE CASCADE
);