
CREATE TABLE chassis (
      chassis_id		bigint NOT NULL,
      group_id			bigint,
      chassisname       character varying(255),
      chassisdnsname	character varying(255),
      ipaddress			character varying(128),
      location			character varying(255),
      numberofslots 	integer,
      numberoffreeslots integer,
      fanOffset         character varying(30),
      enhancedCoolingMode character varying(30),
      countrycode		character varying(10),
      CONSTRAINT chassis_pk PRIMARY KEY (chassis_id),
      
      CONSTRAINT fk_chassis_device FOREIGN KEY (chassis_id)
      REFERENCES infrastructure_device (device_id) MATCH SIMPLE
      ON UPDATE CASCADE ON DELETE CASCADE,
      
      CONSTRAINT fk_chassis_group FOREIGN KEY (group_id)
      REFERENCES infrastructure_group (group_id) MATCH SIMPLE
      ON UPDATE CASCADE ON DELETE CASCADE
);

ALTER TABLE chassis OWNER TO spectre_admin;

	
CREATE TABLE chassis_cmc
(
  cmc_id bigint NOT NULL,
  chassis_id bigint NOT NULL,
  name character varying(255),
  firmware_version character varying(30),
  hardware_version character varying(30),
  last_update_time timestamp without time zone,
  cmc_location character varying(255),
  dns_domain_name character varying(255),
  redundancy_mode character varying(128),
  dhcp_for_dns boolean,
  ipv4_enbaled boolean,
  dhcp_enbaled boolean,
  subnet_mask character varying(255),
  gateway character varying(255),
  preferred_dns_server character varying(255),
  alternate_dns_server character varying(255),
  CONSTRAINT chassis_cmc_pkey PRIMARY KEY (cmc_id),
  CONSTRAINT fk_chassis_cmc_chassis FOREIGN KEY (chassis_id)
  REFERENCES chassis (chassis_id) MATCH SIMPLE
  ON UPDATE CASCADE ON DELETE CASCADE
);

ALTER TABLE chassis_cmc OWNER TO spectre_admin;


CREATE SEQUENCE seq_chassis_cmc_type
 MINVALUE 1000
 MAXVALUE 999999999999
START WITH 1000
NO CYCLE;
ALTER TABLE seq_chassis_cmc_type OWNER TO spectre_admin;



CREATE TABLE chassis_ikvm
(
  ikvm_id bigint NOT NULL,
  chassis_id bigint NOT NULL,
  name character varying(255),
  manufacturer character varying(255),
  partnumber character varying(30),
  firmware_version character varying(30),
  present boolean,
  health character varying(30),
  power_status character varying(30),
  front_panel_enabled boolean,
  access_to_cmc_enabled boolean,
  CONSTRAINT ikvm_pkey PRIMARY KEY (ikvm_id),
  
  CONSTRAINT fk_ikvm_chassis FOREIGN KEY (chassis_id)
  REFERENCES chassis (chassis_id) MATCH SIMPLE
  ON UPDATE CASCADE ON DELETE CASCADE
);

ALTER TABLE chassis_ikvm OWNER TO spectre_admin;

CREATE SEQUENCE seq_chassis_ikvm_type
 MINVALUE 1000
 MAXVALUE 999999999999
START WITH 1000
NO CYCLE;
ALTER TABLE seq_chassis_ikvm_type OWNER TO spectre_admin;

CREATE TABLE chassis_pci
(
  pci_id bigint NOT NULL,
  chassis_id bigint NOT NULL,
  slot_number character varying(128),
  name character varying(255),
  fabric character varying(128),
  power_state bigint,
  server_slot_name character varying(255),
  server_slot_number character varying(128),
  pci_device_id character varying(128),
  pci_vendor_id character varying(128),
  pci_slot_type character varying(128),
  assignment_status character varying(128),
  allocated_slot_power character varying(128),
  server_mapping character varying(128),
  CONSTRAINT chassis_pci_pkey PRIMARY KEY (pci_id),
  
  CONSTRAINT fk_chassis_pci_chassis FOREIGN KEY (chassis_id)
  REFERENCES chassis (chassis_id) MATCH SIMPLE
  ON UPDATE CASCADE ON DELETE CASCADE,
  
  CONSTRAINT fk_chassis_pci_power_state FOREIGN KEY (power_state)
  REFERENCES power_state (power_state) MATCH SIMPLE
  ON UPDATE CASCADE ON DELETE CASCADE
);

ALTER TABLE chassis_pci OWNER TO spectre_admin;

CREATE SEQUENCE seq_chassis_pci_type
 MINVALUE 1000
 MAXVALUE 999999999999
START WITH 1000
NO CYCLE;
ALTER TABLE seq_chassis_pci_type OWNER TO spectre_admin;


CREATE TABLE chassis_power_supply
(
  power_supply_id bigint NOT NULL,
  chassis_id bigint NOT NULL,
  name 	     character varying(255),
  capacity   character varying(30),
  present 	 boolean,
  power_state bigint,
  
  CONSTRAINT chassis_power_supply_pkey PRIMARY KEY (power_supply_id),
  
  CONSTRAINT fk_chassis_power_supply_chassis FOREIGN KEY (chassis_id)
  REFERENCES chassis (chassis_id) MATCH SIMPLE
  ON UPDATE CASCADE ON DELETE CASCADE,
  
  CONSTRAINT fk_chassis_power_supply_power_state FOREIGN KEY (power_state)
  REFERENCES power_state (power_state) MATCH SIMPLE
  ON UPDATE CASCADE ON DELETE CASCADE
  
);

ALTER TABLE chassis_power_supply OWNER TO spectre_admin;

CREATE SEQUENCE seq_chassis_power_supply_type
 MINVALUE 1000
 MAXVALUE 999999999999
START WITH 1000
NO CYCLE;
ALTER TABLE seq_chassis_power_supply_type OWNER TO spectre_admin;


CREATE TABLE raid_controller
(
  raid_controller_id bigint NOT NULL,
  chassis_id bigint NOT NULL,
  fqdd character varying(128),
  status character varying(30),
  rollup_status character varying(30),
  name character varying(255),
  firmware_version character varying(30),
  driver_version character varying(30),
  rebuild_rate integer,
  bgi_rate integer,
  check_consistency_rate integer,
  reconstruct_rate integer,
  patrol_read_rate integer,
  patrol_read_mode character varying(30),
  patrol_read_state character varying(30),
  check_consistancy_mode character varying(30),
  load_balancing_setting character varying(30),
  copy_back_mode character varying(30),
  preserved_cache character varying(30),
  cache_memory_size character varying(30),
  persist_hot_spare character varying(30),
  spindown_unconfigured_drives character varying(30),
  spindown_hot_spare character varying(30),
  time_interval_for_spindown character varying(30),
  security_status character varying(30),
  encryption_mode character varying(30),
  sas_address character varying(30),
  pci_device_id character varying(30),
  pci_subdevice_id character varying(30),
  pci_vendor_id character varying(30),
  pci_subvendor_id character varying(30),
  pci_bus character varying(30),
  pci_device character varying(30),
  pci_function character varying(30),
  bus_width character varying(30),
  slot_length character varying(30),
  slot_type character varying(30),
  capable_speeds character varying(128),
  learn_mode character varying(30),
  high_availability_mode character varying(30),
  
 CONSTRAINT raid_controller_pkey PRIMARY KEY (raid_controller_id),
  
  CONSTRAINT fk_raid_controller_chassis FOREIGN KEY (chassis_id)
  REFERENCES chassis (chassis_id) MATCH SIMPLE
  ON UPDATE CASCADE ON DELETE CASCADE
);

ALTER TABLE raid_controller OWNER TO spectre_admin;

CREATE SEQUENCE seq_raid_controller_type
 MINVALUE 1000
 MAXVALUE 999999999999
START WITH 1000
NO CYCLE;
ALTER TABLE seq_raid_controller_type OWNER TO spectre_admin;


CREATE TABLE storage_enclosure
(
  storage_enclosure_id bigint NOT NULL,
  chassis_id bigint NOT NULL,
  fqdd character varying(128),
  status character varying(30),
  rollup_status character varying(30),
  name character varying(255),
  bay_id integer,
  firmware_version character varying(30),
  sas_address character varying(128),
  slot_count integer,
  
  CONSTRAINT storage_enclosure_pkey PRIMARY KEY (storage_enclosure_id),
  
  CONSTRAINT fk_storage_enclosure_chassis FOREIGN KEY (chassis_id)
  REFERENCES chassis (chassis_id) MATCH SIMPLE
  ON UPDATE CASCADE ON DELETE CASCADE
  
);

ALTER TABLE storage_enclosure OWNER TO spectre_admin;

CREATE SEQUENCE seq_storage_enclosure_type
 MINVALUE 1000
 MAXVALUE 999999999999
START WITH 1000
NO CYCLE;
ALTER TABLE seq_storage_enclosure_type OWNER TO spectre_admin;


CREATE TABLE physical_disk
(
  physical_disk_id bigint NOT NULL,
  raid_controller_id bigint NOT NULL,
  fqdd character varying(128),
  status character varying(30),
  rollup_status character varying(30),
  name character varying(255),
  state character varying(30),
  operation_state character varying(128),
  power_status character varying(30),
  size character varying(30),
  failure_predicted boolean,
  security_status character varying(30),
  bus_protocol character varying(30),
  media_type character varying(30),
  used_raid_disk_space character varying(30),
  available_raid_disk_space character varying(30),
  hot_spare boolean,
  manufacturer character varying(128),
  product_id character varying(128),
  revision character varying(30),
  serial_number character varying(128),
  part_number character varying(128),
  negotiated_speed character varying(30),
  capable_speed character varying(30),
  manufactured_day integer,
  manufactured_week integer,
  manufactured_year integer,
  sas_address character varying(128),
  form_factor character varying(30),
  
  CONSTRAINT physical_disk_pkey PRIMARY KEY (physical_disk_id),
  
  CONSTRAINT fk_physical_disk_raid_controller FOREIGN KEY (raid_controller_id)
  REFERENCES raid_controller (raid_controller_id) MATCH SIMPLE
  ON UPDATE CASCADE ON DELETE CASCADE
);

ALTER TABLE physical_disk OWNER TO spectre_admin;

CREATE SEQUENCE seq_physical_disk_type
 MINVALUE 1000
 MAXVALUE 999999999999
START WITH 1000
NO CYCLE;
ALTER TABLE seq_physical_disk_type OWNER TO spectre_admin;


CREATE TABLE virtual_disk
(
  virtual_disk_id bigint NOT NULL,
  raid_controller_id bigint NOT NULL,
  fqdd character varying(128),
  status character varying(30),
  name character varying(255),
  rollup_status character varying(30),
  state character varying(30),
  operational_state character varying(30),
  layout character varying(30),
  size character varying(30),
  available_protocols character varying(30),
  media_type character varying(30),
  read_policy character varying(30),
  write_policy character varying(30),
  stripe_size character varying(30),
  disk_cache_policy character varying(30),
  bad_block_found boolean,
  secured boolean,
  remaining_redundancy integer,
  enhanced_cache character varying(30),
  virtual_adapter_1_read_policy character varying(30),
  virtual_adapter_2_read_policy character varying(30),
  virtual_adapter_3_read_policy character varying(30),
  virtual_adapter_4_read_policy character varying(30),
  
  CONSTRAINT virtual_disk_pkey PRIMARY KEY (virtual_disk_id),
  
  CONSTRAINT fk_virtual_disk_raid_controller FOREIGN KEY (raid_controller_id)
  REFERENCES raid_controller (raid_controller_id) MATCH SIMPLE
  ON UPDATE CASCADE ON DELETE CASCADE
  
);

ALTER TABLE virtual_disk OWNER TO spectre_admin;

CREATE SEQUENCE seq_virtual_disk_type
 MINVALUE 1000
 MAXVALUE 999999999999
START WITH 1000
NO CYCLE;
ALTER TABLE seq_virtual_disk_type OWNER TO spectre_admin;

CREATE TABLE chassis_fan
(
  fan_id bigint NOT NULL,
  chassis_id bigint NOT NULL,
  name character varying(255),
  present boolean,
  power_state bigint,
  status character varying(30),
  reading character varying(30),
  units character varying(30),
  lc character varying(30),
  uc character varying(30),
  lw character varying(30),
  uw character varying(30),
  CONSTRAINT fan_pkey PRIMARY KEY (fan_id),
  CONSTRAINT fk_fan_chassis FOREIGN KEY (chassis_id)
  REFERENCES chassis (chassis_id) MATCH SIMPLE
  ON UPDATE CASCADE ON DELETE CASCADE
);

ALTER TABLE chassis_fan OWNER TO spectre_admin;

CREATE SEQUENCE SEQ_CHASSIS_FAN_TYPE
 MINVALUE 1000
 MAXVALUE 999999999999
START WITH 1000
NO CYCLE;
ALTER TABLE SEQ_CHASSIS_FAN_TYPE OWNER TO spectre_admin;

CREATE TABLE chassis_temperature_sensor
(
  temperature_sensor_id bigint NOT NULL,
  chassis_id bigint NOT NULL,
  name character varying(255),
  status character varying(30),
  reading character varying(30),
  units character varying(30),
  lc character varying(30),
  uc character varying(30),
  lw character varying(30),
  uw character varying(30),
  num character varying(30),
  CONSTRAINT temperature_sensor_pkey PRIMARY KEY (temperature_sensor_id),
  CONSTRAINT fk_temperature_sensor_chassis FOREIGN KEY (chassis_id)
  REFERENCES chassis (chassis_id) MATCH SIMPLE
  ON UPDATE CASCADE ON DELETE CASCADE
);

ALTER TABLE chassis_temperature_sensor OWNER TO spectre_admin;

CREATE SEQUENCE SEQ_CHASSIS_TEMPERATURE_SENSOR_TYPE
 MINVALUE 1000
 MAXVALUE 999999999999
START WITH 1000
NO CYCLE;
ALTER TABLE SEQ_CHASSIS_TEMPERATURE_SENSOR_TYPE OWNER TO spectre_admin;

CREATE TABLE chassis_license
(
  license_id bigint NOT NULL,
  chassis_id bigint NOT NULL,
  device_name character varying(255),
  status character varying(30),
  device_description character varying(1024),
  name character varying(255),
  license_status character varying(30),
  transaction_id character varying(30),
  license_description character varying(1024),
  license_type character varying(50),
  unique_identifier character varying(50),
  entitlement_id character varying(30),
  license_bound character varying(30),
  expiration character varying(30),
  device character varying(30),
  CONSTRAINT license_pkey PRIMARY KEY (license_id),
  CONSTRAINT fk_license_chassis FOREIGN KEY (chassis_id)
  REFERENCES chassis (chassis_id) MATCH SIMPLE
  ON UPDATE CASCADE ON DELETE CASCADE
);

ALTER TABLE chassis_license OWNER TO spectre_admin;

CREATE SEQUENCE SEQ_CHASSIS_LICENSE_TYPE
 MINVALUE 1000
 MAXVALUE 999999999999
START WITH 1000
NO CYCLE;
ALTER TABLE SEQ_CHASSIS_LICENSE_TYPE OWNER TO spectre_admin;

